@@ -1,5 +1,5 @@
 /***************************************************************************
-* Copyright (c) 2016, Johan Mabille and Sylvain Corlay                     *
+* Copyright (c) 2016, Johan Mabille, Sylvain Corlay and Wolf Vollprecht    *
 *                                                                          *
 * Distributed under the terms of the BSD 3-Clause License.                 *
 *                                                                          *
@@ -125,7 +125,7 @@ namespace xt
         template <class S>
         const_stepper stepper_begin(const S& shape) const noexcept;
         template <class S>
-        const_stepper stepper_end(const S& shape) const noexcept;
+        const_stepper stepper_end(const S& shape, layout_type l) const noexcept;
 
     private:
         CT m_e;
@@ -281,10 +281,7 @@ namespace xt
     template <class It>
     inline auto xbroadcast<CT, X>::element(It, It last) const -> const_reference
     {
-        // Workaround MSVC bug. m_e.element(last - dimension(), last) does not build.
-        It first = last;
-        first -= dimension();
-        return m_e.element(first, last);
+        return m_e.element(last - dimension(), last);
     }
     //@}
 
@@ -329,10 +326,10 @@ namespace xt
 
     template <class CT, class X>
     template <class S>
-    inline auto xbroadcast<CT, X>::stepper_end(const S& shape) const noexcept -> const_stepper
+    inline auto xbroadcast<CT, X>::stepper_end(const S& shape, layout_type l) const noexcept -> const_stepper
     {
         // Could check if (broadcastable(shape, m_shape)
-        return m_e.stepper_end(shape);
+        return m_e.stepper_end(shape, l);
     }
 }
 
